@@ -1,4 +1,4 @@
-# $Id: windfinder.py 1067 2014-10-18 03:35:52Z mwall $
+# $Id: windfinder.py 1156 2014-12-03 19:44:45Z mwall $
 # Copyright 2014 Matthew Wall
 
 """
@@ -34,9 +34,13 @@ import urllib2
 import weewx
 import weewx.restx
 import weewx.units
-from weeutil.weeutil import to_bool
+from weeutil.weeutil import to_bool, accumulateLeaves
 
-VERSION = "0.3"
+VERSION = "0.4"
+
+if weewx.__version__ < "3":
+    raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
+                                   weewx.__version__)
 
 def logmsg(level, msg):
     syslog.syslog(level, 'restx: WindFinder: %s' % msg)
@@ -52,17 +56,11 @@ def logerr(msg):
 
 def _mps_to_knot(v):
     from_t = (v, 'meter_per_second', 'group_speed')
-    to_t = weewx.units.convert(from_t, 'knot')
-    return to_t.value
+    return weewx.units.convert(from_t, 'knot')[0]
 
 class WindFinder(weewx.restx.StdRESTbase):
-    """Upload using the WindFinder protocol."""
-
     def __init__(self, engine, config_dict):
-        """Initialize for upload to WindFinder.  This service supports the
-        standard restful options plus the following:
-
-        Required parameters:
+        """This service recognizes standard restful options plus the following:
 
         station_id: WindFinder station identifier
 
@@ -71,20 +69,21 @@ class WindFinder(weewx.restx.StdRESTbase):
         super(WindFinder, self).__init__(engine, config_dict)
         loginf("service version is %s" % VERSION)
         try:
-            site_dict = weewx.restx.get_dict(config_dict, 'WindFinder')
+            site_dict = config_dict['StdRESTful']['WindFinder']
+            site_dict = accumulateLeaves(site_dict, max_level=1)
             site_dict['station_id']
             site_dict['password']
         except KeyError, e:
             logerr("Data will not be posted: Missing option %s" % e)
             return
-        site_dict.setdefault('database_dict', config_dict['Databases'][config_dict['StdArchive']['archive_database']])
+        site_dict['manager_dict'] = weewx.manager.get_manager_dict(
+            config_dict['DataBindings'], config_dict['Databases'], 'wx_binding')
 
         self.archive_queue = Queue.Queue()
         self.archive_thread = WindFinderThread(self.archive_queue, **site_dict)
         self.archive_thread.start()
         self.bind(weewx.NEW_ARCHIVE_RECORD, self.new_archive_record)
-        loginf("Data will be uploaded for station_id=%s" %
-               site_dict['station_id'])
+        loginf("Data will be uploaded for %s" % site_dict['station_id'])
 
     def new_archive_record(self, event):
         self.archive_queue.put(event.record)
@@ -100,14 +99,14 @@ class WindFinderThread(weewx.restx.RESTThread):
                  'rain':          ('rainRate',    '%.2f'), # mm/hr
                  }
 
-    def __init__(self, queue, station_id, password, database_dict,
+    def __init__(self, queue, station_id, password, manager_dict,
                  server_url=_SERVER_URL, skip_upload=False,
                  post_interval=300, max_backlog=sys.maxint, stale=None,
                  log_success=True, log_failure=True,
                  timeout=60, max_tries=3, retry_wait=5):
         super(WindFinderThread, self).__init__(queue,
                                                protocol_name='WindFinder',
-                                               database_dict=database_dict,
+                                               manager_dict=manager_dict,
                                                post_interval=post_interval,
                                                max_backlog=max_backlog,
                                                stale=stale,
@@ -121,11 +120,11 @@ class WindFinderThread(weewx.restx.RESTThread):
         self.server_url = server_url
         self.skip_upload = to_bool(skip_upload)
 
-    def process_record(self, record, archive):
-        r = self.get_record(record, archive)
+    def process_record(self, record, dbm):
+        r = self.get_record(record, dbm)
         url = self.get_url(r)
         if self.skip_upload:
-            logdbg("skipping upload")
+            loginf("skipping upload")
             return
         req = urllib2.Request(url)
         req.add_header("User-Agent", "weewx/%s" % weewx.__version__)
